com.biffweb.background


fx-handlersclj

A biff.fx handlers map containing :biff.background.fx/submit-jobs submit-jobs

A biff.fx handlers map containing
`:biff.background.fx/submit-jobs submit-jobs`
sourceraw docstring

moduleclj

(module)

A biff.core module that:

  • Provides :biff.fx/handlers.
  • Aggregates :biff.background/tasks and :biff.background/queues from other modules. Tasks and queues are only aggregated on startup, not whenever modules change.
A biff.core module that:

- Provides :biff.fx/handlers.
- Aggregates :biff.background/tasks and :biff.background/queues from other
  modules. Tasks and queues are only aggregated on startup, not whenever
  modules change.
sourceraw docstring

submit-jobsclj

(submit-jobs {:biff.background/keys [queues]} queue-id jobs)

Adds jobs to the specified queue.

queue-id - :biff.background/queue-id jobs - Sequence of :biff.background/job

conjs a shutdown function on the :biff.core/stop key.

Adds `jobs` to the specified queue.

queue-id - :biff.background/queue-id
jobs     - Sequence of :biff.background/job

`conj`s a shutdown function on the :biff.core/stop key.
sourceraw docstring

use-queuesclj

(use-queues {:keys [biff.background/queues] :as ctx})

Initializes a queue and fixed executor thread pool for each entry in queues.

See :biff.background/queues. conjs a shutdown function on the :biff.core/stop key.

Initializes a queue and fixed executor thread pool for each entry in
`queues`.

See :biff.background/queues. `conj`s a shutdown function on the
:biff.core/stop key.
sourceraw docstring

use-scheduled-tasksclj

(use-scheduled-tasks {:keys [biff.background/tasks] :as ctx})

Calls chime.core/chime-at for each task.

Each task function receives ctx as its sole argument.

Calls chime.core/chime-at for each `task`.

Each task function receives ctx as its sole argument.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries